import { ProcessState, UUID } from "."

export interface Farm {
  id: UUID
  name: string
}

export interface GPU {
  id: UUID
  index: number
  name: string
  ram_total: number
}

type AgentLight = {
  id: UUID
  farm: Farm
  hostname: string
  cpu_cores: number
  cpu_frequency: number
  ram_total: number
  last_ping: string
  gpus: GPU[]
} & ({
  active: true
  cpu_load: number
  ram_load: number
} | {
  active: false
  cpu_load: number | null
  ram_load: number | null
})

export type AgentState = AgentLight & {
  running_tasks_count: number
}

export type AgentDetails = AgentLight & {
  running_tasks: string[]
}

export interface Task {
  id: UUID
  run: number
  depth: number
  slug: string
  state: ProcessState
  parents: UUID[]
  tags: string[]
  shm_size: string
  logs: string
  full_log: string
  agent: AgentLight | null
  gpu: GPU | null
  extra_files: Record<string, string>
}

export interface Artifact {
  id: UUID
  path: string
  size: number
  content_type: string
  url: string
  s3_put_url: string | null
  created: string
  updated: string
}
