import { assert } from 'chai'
import { highlight } from '@/helpers'

describe('helpers/text', () => {
  describe('highlight', () => {
    it('highlights keywords in a text', () => {
      assert.deepStrictEqual(
        highlight('I fell asleep amid the flowers', ['sleep', 'space', 'bedroom', 'flower']),
        [
          { text: 'I fell a', hl: false },
          { text: 'sleep', hl: true },
          { text: ' amid the ', hl: false },
          { text: 'flower', hl: true },
          { text: 's', hl: false }
        ]
      )
    })
    it('ignores a text with no keywords', () => {
      assert.deepStrictEqual(
        highlight('For a couple of hours', []),
        [
          { text: 'For a couple of hours', hl: false }
        ]
      )
    })
    it('highlights keywords following each other', () => {
      assert.deepStrictEqual(
        highlight('On a beautiful day', ['beau', 'tiful']),
        [
          { text: 'On a ', hl: false },
          { text: 'beau', hl: true },
          { text: 'tiful', hl: true },
          { text: ' day', hl: false }
        ]
      )
    })
    it('ignores an empty text', () => {
      assert.deepStrictEqual(
        highlight('', ['no', 'sentence']),
        [
          { text: '', hl: false }
        ]
      )
    })
    it('highlights a text with overlapping keywords', () => {
      assert.deepStrictEqual(
        highlight('ultramafic', ['ultra', 'AMA', 'maf']),
        [
          { text: 'ultra', hl: true },
          { text: 'ma', hl: true },
          { text: 'f', hl: true },
          { text: 'ic', hl: false }
        ]
      )
    })
    it('only highlights the first occurrences', () => {
      assert.deepStrictEqual(
        highlight('Many matches', ['ma']),
        [
          { text: 'Ma', hl: true },
          { text: 'ny matches', hl: false }
        ]
      )
    })
    it('highlights correctly with spaces paddings', () => {
      assert.deepStrictEqual(
        highlight('anormal', ['', ' ', ' an ']),
        [
          { text: 'an', hl: true },
          { text: 'ormal', hl: false }
        ]
      )
    })
  })
})
